@@ -4,7 +4,7 @@
 
 module gtool 
 
-    use gtool_device
+    use gtool_frame
     implicit none
 
 contains
