@@ -2,9 +2,15 @@
 ! Copyright (C) by TOYODA Eizi, 2000.  All rights reserved.
 ! vi: set sw=4 ts=8:
 
+!
+! {W[̓foCX̃I[vƃN[YsB
+! dcl ͂ӂ̃foCX𓯎ɈȂ̂ŁA͔r
+! sƂɂȂł낤B
+! 
+
 module gtool_device 
 
-    use gtool_frame
+    use dcl
     implicit none
 
     type GT_DEVICE
@@ -19,10 +25,6 @@ module gtool_device
 	module procedure GtoolDeviceClose
     end interface
 
-    interface Display
-	module procedure GtoolFigureDisplay
-    end interface
-
     logical, private, save:: First = .TRUE.
 
 contains
@@ -47,10 +49,4 @@ contains
     	dev%ws_id = -1
     end subroutine
 
-    subroutine GtoolFigureDisplay(dev, fig)
-	type(GT_DEVICE), intent(inout):: dev
-	type(GT_FIGURE), intent(in):: fig
-    continue
-    end subroutine
-
 end module
