@@ -138,9 +138,11 @@ contains
 	integer:: mode, status
     continue
 	mode = NF_NOWRITE
-	if (present(writable) .and. writable) then
-	    mode = ior(mode, NF_WRITE)
-	    result%writable = .TRUE.
+	if (present(writable)) then
+	    if (writable) then
+	        mode = ior(mode, NF_WRITE)
+	        result%writable = .TRUE.
+	    endif
 	else
 	    result%writable = .FALSE.
 	endif
