@@ -53,8 +53,10 @@ module netcdf_slice
 
     interface Slice
 	module procedure NetcdfSliceDimension
+	module procedure NetcdfSliceDimensionOrd
 	module procedure NetcdfSliceDimensionByName
 	module procedure NetcdfSliceDimensionSetIndex
+	module procedure NetcdfSliceDimensionOrdSetIndex
     end interface
 
     interface WholeVariable
@@ -159,6 +161,20 @@ contains
 	nullify(result%body)
     end function
 
+    function NetcdfSliceDimensionOrd(limit, dimord) result(result)
+	type(NC_SLICE)::			result
+	type(NC_LIMIT), intent(in)::		limit
+	integer, intent(in)::			dimord
+	integer::		i
+    continue
+	if (.not. associated(limit%slices)) goto 999
+	if (dimord > size(limit%slices)) goto 999
+	result%body => limit%slices(dimord)
+	return
+999	continue
+	nullify(result%body)
+    end function
+
     function NetcdfSliceDimensionByName(limit, dimname) result(result)
 	type(NC_SLICE)::			result
 	type(NC_LIMIT), intent(in)::		limit
@@ -197,6 +213,28 @@ contains
 	result = .TRUE.
     end function
 
+    logical function NetcdfSliceDimensionOrdSetIndex(limit, dimord, start, &
+    & stride, count) result(result)
+	type(NC_LIMIT), intent(in)::		limit
+	integer, intent(in)::			dimord
+	integer, intent(in)::			start
+	integer, intent(in), optional::		stride, count
+	type(NC_SLICE)::			it
+    continue
+	it = Slice(limit, dimord)
+	if (.not. associated(it%body)) then
+	    result = .FALSE.; return
+	endif
+	if (present(count) .and. present(stride)) then
+	    it = (/start, count, stride/)
+	else if (present(count)) then
+	    it = (/start, count/)
+	else
+	    it = start
+	endif
+	result = .TRUE.
+    end function
+
     !
     ! --- GENERIC ASSIGNMENT ---
     !
