@@ -133,7 +133,7 @@ contains
     logical function NetcdfVariableError(var) result(result)
     	type(NC_VARIABLE), intent(in)::	var
     continue
-    	result = (var%id > 0)
+    	result = (var%id < 0)
     end function
 
     integer function NetcdfVariableId(var) result(result)
