@@ -1,15 +1,15 @@
 program test
-	use netcdf_file
-	use netcdf_dimension
+	use netcdf
+
 	type(NC_FILE)::		file
 	type(NC_ERROR)::	err
 	type(NC_DIMENSION)::	lat
 	character(len = 64)::	buf
 	logical::		ok
 
-	err = create(file, 'foo.nc')
+	err = create(file, 'test.nc')
 	call assert(err)
-	print *, 'test file foo.nc created'
+	print *, 'test file test.nc created'
 	lat = Dimension(file, 'lat', 128)
 	if (.error. lat) call assert(NetcdfLastError())
 	call NetcdfSaveError(NF_NOERR, '', '')
