@@ -1,5 +1,5 @@
 program test
-	use netcdf_io
+	use netcdf
 	implicit none
 
 	integer, parameter::	LATGRIDS = 128
@@ -10,14 +10,13 @@ program test
 	type(NC_DIMENSION)::	lat, lon
 	type(NC_VARIABLE)::	u
 	type(NC_LIMIT)::	lim
-	real::			uvalue(LATGRIDS, LONGRIDS, 1, 1, 1, 1)
-	real, pointer::		upointer(:, :, :, :, :, :)
+	real::			uvalue(LATGRIDS, LONGRIDS, 1, 1, 1, 1, 1)
+	real, pointer::		upointer(:, :, :, :, :, :, :)
 	integer::		i, j
 	logical::		ok
 
-	err = create(file, 'foo.nc')
-	call assert(err)
-	print *, 'test file foo.nc created'
+	call create(file, 'test.nc')
+	print *, 'test file test.nc created'
 
 	lat = Dimension(file, 'lat', LATGRIDS)
 	if (.error. lat) call assert(NetcdfLastError())
@@ -27,10 +26,10 @@ program test
 	u = Variable(file, 'u', NF_FLOAT, (/lat, lon/))
 	call assert(NetcdfLastError())
 
-	err = enddefmode(file)
+	err = EndDefine(file)
 
 	uvalue = reshape((/((i * j, i = 1, LATGRIDS), j = 1, LONGRIDS)/), &
-		& (/LATGRIDS, LONGRIDS, 1, 1, 1, 1/))
+		& (/LATGRIDS, LONGRIDS, 1, 1, 1, 1, 1/))
 	
 	ok = put_real(u, uvalue)
 	if (.not. ok) call assert(NetcdfLastError())
@@ -40,10 +39,9 @@ program test
 	if (.not. Slice(lim, 'lon', 1)) stop 'slice'
 	upointer => get_real(u, lim)
 	print *, char(string(lim))
-	print *, upointer(1, 1, 1, 1, 1, 1)
+	print *, upointer(1:6, 1, 1, 1, 1, 1, 1)
 	call dispose(lim)
 	deallocate(upointer)
 
-	err = close(file)
-	call assert(err)
+	call close(file)
 end program
