@@ -3,10 +3,10 @@
 ! vi: set ts=8 sw=4:
 
 ! 
-!	{W[̓|C^gȂ 508 ܂ł
-!	ϒێ\̂񋟂B
+!	ܥ⥸塼ϥݥ󥿤ȤʤĶ 508 ޤǤ
+!	Ĺʸݻ빽¤Τ󶡤롣
 
-module iso_varying_string
+module dc_string_internal
 
     implicit none
 
@@ -14,6 +14,7 @@ module iso_varying_string
     public VARYING_STRING, len, var_str, char, get, put, put_line, &
 	& assignment(=), operator(==), operator(/=), operator(//), &
 	& operator(<), operator(<=), operator(>), operator(>=), &
+	& index, scan, verify, extract, &
 	& disposable
 
     integer, parameter::		STRING_MAX = 508
@@ -40,6 +41,10 @@ module iso_varying_string
 	module procedure string_to_char_length
     end interface
 
+    interface extract
+	module procedure extract
+    end interface
+
     interface get
 	module procedure string_get
 	module procedure string_get_default
@@ -127,11 +132,11 @@ module iso_varying_string
 contains
 
     !
-    ! === J葱 ===
+    ! === ³ ===
     !
 
     !
-    !  disposable ֐̎
+    !  disposable ؿμ
     !
 
     subroutine string_set_disposable(str)
@@ -141,7 +146,7 @@ contains
     end subroutine
 
     !
-    !  len ֐̎
+    !  len ؿμ
     !
 
     integer function string_len(str) result(result)
@@ -151,7 +156,7 @@ contains
     end function
 
     !
-    !  var_str ֐̎
+    !  var_str ؿμ
     !
 
     type(VARYING_STRING) function char_to_string(char) result(result)
@@ -159,12 +164,12 @@ contains
     continue
     	if (len(char) > STRING_MAX) call warn_limit('cast')
 	result%len = min(len(char), STRING_MAX)
-	! ͖
+	! Ψ̵
     	result%body = char
     end function
 
     !
-    !  char ֐̎
+    !  char ؿμ
     !
 
     function string_to_char_all(str) result(result)
@@ -183,7 +188,7 @@ contains
     end function
 
     !
-    ! ̑̎
+    ! ʸμ
     !
 
     subroutine string_let_char(str, char)
@@ -202,7 +207,7 @@ contains
     end subroutine
 
     !
-    !  // Zq̎
+    !  // 黻Ҥμ
     !
 
     type(VARYING_STRING) function string_add_string(lhs, rhs) result(result)
@@ -227,7 +232,7 @@ contains
     end function
 
     !
-    ! ̉Zq == ̎
+    ! α黻 == μ
     !
 
     logical function string_eq_string(lhs, rhs) result(result)
@@ -251,7 +256,7 @@ contains
     end function
 
     !
-    ! ̉Zq /= ̎
+    ! α黻 /= μ
     !
 
     logical function string_ne_string(lhs, rhs) result(result)
@@ -275,7 +280,7 @@ contains
     end function
 
     !
-    ! ̉Zq < ̎
+    ! α黻 < μ
     !
 
     logical function string_lt_string(lhs, rhs) result(result)
@@ -299,7 +304,7 @@ contains
     end function
 
     !
-    ! ̉Zq <= ̎
+    ! α黻 <= μ
     !
 
     logical function string_le_string(lhs, rhs) result(result)
@@ -323,7 +328,7 @@ contains
     end function
 
     !
-    ! ̉Zq > ̎
+    ! α黻 > μ
     !
 
     logical function string_gt_string(lhs, rhs) result(result)
@@ -347,7 +352,7 @@ contains
     end function
 
     !
-    ! ̉Zq >= ̎
+    ! α黻 >= μ
     !
 
     logical function string_ge_string(lhs, rhs) result(result)
@@ -371,7 +376,7 @@ contains
     end function
 
     !
-    ! o
+    ! 
     !
 
     subroutine string_get_default(str, maxlen, iostat)
@@ -401,9 +406,9 @@ contains
 	do
 	    if (alreadyread >= maxsize) return
 	    buflen = min(BUFFERSIZE, maxsize - alreadyread)
-	    ! SUPER-UX ΍
+	    ! SUPER-UX к
 	    buffer = ''		
-	    ! ǂݎ
+	    ! ɤ߼
 	    if (unit >= 0) then
 		read(unit=unit, fmt='(A)', advance='NO', &
 		    & size=nowread, eor=100, iostat=ios) buffer(1: buflen)
@@ -420,7 +425,7 @@ contains
 		    stop
 		endif
 	    endif
-	    ! Ȃ SUPER-UX SX4 Fortran 90 ł͍słȂ
+	    ! ʤ SUPER-UX SX4 Fortran 90 ǤϹǤʤ
 	    if (nowread == 0 .and. len_trim(buffer) /= 0) then
 		nowread = len_trim(buffer)
 		goto 100
@@ -546,41 +551,50 @@ contains
     end subroutine
 
     !
-    ! --- gݍ݊֐̏㏑ ---
+    ! --- Ȥ߹ߴؿξ ---
     !
 
     !
-    ! index ̑p
+    ! index 
     !
 
     function string_index_string(str, substring, back) result(result)
 	integer::				result
 	type(VARYING_STRING), intent(in)::	str, substring
-	logical, optional::			back
+	logical, intent(in), optional::		back
+	logical:: backward
     continue
-	result = index(char(str), char(substring), back)
+	backward = .FALSE.
+	if (present(back)) backward = back
+	result = index(char(str), char(substring), backward)
     end function
 
     function string_index_char(str, substring, back) result(result)
 	integer::				result
 	type(VARYING_STRING), intent(in)::	str
 	character(len = *), intent(in)::	substring
-	logical, optional::			back
+	logical, intent(in), optional::		back
+	logical:: backward
     continue
-	result = index(char(str), substring, back)
+	backward = .FALSE.
+	if (present(back)) backward = back
+	result = index(char(str), substring, backward)
     end function
 
     function char_index_string(str, substring, back) result(result)
 	integer::				result
 	character(len = *), intent(in)::	str
 	type(VARYING_STRING), intent(in)::	substring
-	logical, optional::			back
+	logical, intent(in), optional::		back
+	logical:: backward
     continue
-	result = index(str, char(substring), back)
+	backward = .FALSE.
+	if (present(back)) backward = back
+	result = index(str, char(substring), backward)
     end function
 
     !
-    ! scan ̑p
+    ! scan 
     !
 
     function string_scan_string(str, set, back) result(result)
@@ -601,7 +615,7 @@ contains
     end function
 
     !
-    ! verify ̑p
+    ! verify 
     !
 
     function string_verify_string(str, set, back) result(result)
@@ -622,7 +636,23 @@ contains
     end function
 
     !
-    ! === Iɗp ===
+    ! --- ߼³ ---
+    !
+
+    type(VARYING_STRING) function extract(string, start, finish)
+	type(VARYING_STRING), intent(in):: string
+	integer, intent(in), optional::	start, finish
+	integer:: first, last
+    continue
+	first = 1
+	if (present(start)) first = max(start, first)
+	last = len(string)
+	if (present(finish)) last = min(finish, last)
+	extract = string%body(first: last)
+    end function
+
+    !
+    ! === Ū ===
     !
 
     subroutine warn_limit(cause)
@@ -635,7 +665,7 @@ contains
 	    & STRING_MAX, ' by ', cause
     end subroutine
 
-    ! A // Zq
+    ! Ϣ // 黻
     type(VARYING_STRING) function char_add_char(lhs, rhs) result(result)
 	character(len = *), intent(in)::	lhs, rhs
 	integer::				lhslen, first, last
@@ -656,4 +686,4 @@ contains
 	result%body(first: last) = rhs
     end function
 
-end module iso_varying_string
+end module 
